MongoDB C Driver
================

**A Cross Platform MongoDB Client Library for C**

The MongoDB C Driver, also known as "libmongoc", is a library for using MongoDB from C applications, and for writing MongoDB drivers in higher-level languages.

It depends on `libbson <libbson/current/index.html>`_ to generate and parse BSON documents, the native data format of MongoDB.

Download
--------

Latest release: :download-link:`mongoc`

Documentation
-------------

`Installation <libmongoc/current/installing.html>`_

`Tutorial <libmongoc/current/tutorial.html>`_

`libmongoc reference <libmongoc/current/index.html>`_

`libbson reference <libbson/current/index.html>`_

How To Ask For Help
-------------------

For help using the driver: `MongoDB Community Forums <https://community.mongodb.com/tags/c/drivers-odms-connectors/7/c-driver>`_.

To file a bug or feature request: `MongoDB Jira Issue Tracker <https://jira.mongodb.org/browse/CDRIVER>`_.

Documentation for Older Versions
--------------------------------

.. toctree::
   :titlesonly:

   libmongoc-releases
   libbson-releases
